@@ -35,10 +35,3 @@ class RequestDelete(Request):
     def __init__(self, url, **kwargs):
         kwargs.update({'url': url, 'method': 'DELETE'})
         super().__init__(**kwargs)
-
-
-if __name__ == '__main__':
-    response = RequestGet(url='https://www.baidu.com', titan_meta={'name': '张三'}).send()[1]
-    print(response.text)
-    print(response.titan)
-    print(response.titan_meta)
